#!/usr/bin/python

import sys

def print_header(label):
  w = 78 - len(label)
  w1 = w / 2
  w2 = w - w1
  print w1 * '=', label, w2 * '='

def print_result(name, count, size):
  print '%39s has %6d fulltexts => %10d bytes' % (name, count, size)

def main():
  total_fulltext_size = 0L
  total_fulltext_count = 0
  trunk_fulltext_size = 0L
  trunk_fulltext_count = 0
  tag_fulltext_size = {}
  tag_fulltext_count = {}
  branch_fulltext_size = {}
  branch_fulltext_count = {}
  while 1:
    line = sys.stdin.readline()
    if not line:
      break
    i = line.find(' ')
    size = int(line[:i])
    path = line[i+1:-1]
    path_split = path[1:].split('/')
    # Don't count unlabeled braches for now
    if path_split[0] == 'branches' and path_split[1][:10] == 'unlabeled-':
      continue
    total_fulltext_size += size
    total_fulltext_count += 1
    if path_split[0] == 'trunk':
      trunk_fulltext_size += size
      trunk_fulltext_count += 1
    else:
      name = path_split[1]
      if path_split[0] == 'tags':
        if not name in tag_fulltext_size:
          tag_fulltext_size[name] = 0L
          tag_fulltext_count[name] = 0
        tag_fulltext_size[name] += size
        tag_fulltext_count[name] += 1
      elif path_split[0] == 'branches':
        if not name in branch_fulltext_size:
          branch_fulltext_size[name] = 0L
          branch_fulltext_count[name] = 0
        branch_fulltext_size[name] += size
        branch_fulltext_count[name] += 1
      else:
        raise 'parse error'

  print_header('TOTAL')
  print_result('The whole repository', total_fulltext_count,
               total_fulltext_size)

  print
  print_header('TRUNK')
  print_result('trunk', trunk_fulltext_count, trunk_fulltext_size)

  print
  print_header('TAGS')
  tags = tag_fulltext_size.keys()
  tags.sort(lambda t1, t2: cmp(tag_fulltext_size[t2], tag_fulltext_size[t1]))
  for tag in tags:
    print_result(tag, tag_fulltext_count[tag], tag_fulltext_size[tag])

  print
  print_header('BRANCHES')
  branches = branch_fulltext_size.keys()
  branches.sort(lambda b1, b2: cmp(branch_fulltext_size[b2],
                                   branch_fulltext_size[b1]))
  for branch in branches:
    print_result(branch, branch_fulltext_count[branch],
                 branch_fulltext_size[branch])

if __name__ == '__main__':
  main()
