#!/usr/bin/python

# Standard modules
import sys, os, re, codecs, textwrap
# We need a bsddb linked to the same version of Berkeley DB as Subversion is
try:
  import bsddb3 as bsddb
except ImportError:
  import bsddb
from bsddb.db import *
# Local support modules
import skel, svnfs

# Parse arguments
if len(sys.argv) == 2:
  dbhome = os.path.join(sys.argv[1], 'db')
  if not os.path.exists(dbhome):
    sys.stderr.write("%s: '%s' is not a valid svn repository\n" %
        (sys.argv[0], dbhome))
    sys.exit(1)
else:
  sys.stderr.write("Usage: %s <svn-repository>\n" % sys.argv[0])
  sys.exit(1)

def main():
  ctx = svnfs.Ctx()
  try:
    ctx.open(DBEnv(), dbhome, readonly=1)

    cur = ctx.nodes_db.cursor()
    try:
      rec = cur.first()
      data = {}
      seen_reps = {}
      total_strlen = 0L
      while rec:
        if rec[0] == 'next-key':
          rec = cur.next()
          continue
        nd = skel.Node(rec[1])
        if nd.kind == 'file':
          r = skel.Rep(ctx.reps_db[nd.datarep])
          if r.kind == 'fulltext' and nd.datarep not in seen_reps:
            seen_reps[nd.datarep] = None
            strlen = len(ctx.get_whole_string(r.str))
            sys.stdout.write('%d %s\n' % (strlen, nd.createpath))
            sys.stdout.flush()
        rec = cur.next()
    finally:
      cur.close()

  finally:
    ctx.close()

if __name__ == '__main__':
  main()
